/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 02884
 |        NATIONAL TREATMENT IMPROVEMENT EVALUATION STUDY (NTIES),
 |                               1992-1997
 |            (DATASET 0005: NTIES CLINICAL UNIT DATA (NCLU))
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\02884-0005-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE dircoll   -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE dirgrad   -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE dircred   -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE diryears  -9='(-9) NO DATA' 1='(1) 0-4' 2='(2) 5 or more' ;
  VALUE dirsex    -9='(-9) NO DATA' 1='(1) Male' 2='(2) Female' ;
  VALUE direthni  -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE yrskeypf  -9='(-9) NO DATA' -3='(-3) MISSING' 1='(1) 0-2 years' 2='(2) 3-6 years'
                  3='(3) 7+ years' ;
  VALUE yrskey0f  -9='(-9) NO DATA' 1='(1) 0-2 years' 2='(2) 3-6 years' 3='(3) 7+ years' ;
  VALUE pmalestf  -9='(-9) NO DATA' -3='(-3) MISSING' 1='(1) 0-33%' 2='(2) 34-50%' 3='(3) 51-100%' ;
  VALUE pminostf  -9='(-9) NO DATA' -3='(-3) MISSING' 1='(1) 0-33%' 2='(2) 34-66%' 3='(3) 67-100%' ;
  VALUE anycase   -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE ftemed    -9='(-9) NO DATA' -3='(-3) MISSING' ;
  VALUE ftecouns  -9='(-9) NO DATA' -3='(-3) MISSING' ;
  VALUE fteadmin  -9='(-9) NO DATA' -3='(-3) MISSING' ;
  VALUE ctenure   -9='(-9) NO DATA' ;
  VALUE cadcases  -9='(-9) NO DATA' ;
  VALUE colgrad   -9='(-9) NO DATA' ;
  VALUE cgender   -9='(-9) NO DATA' ;
  VALUE cgenmtch  -9='(-9) NO DATA' ;
  VALUE crace     -9='(-9) NO DATA' ;
  VALUE cracmtch  -9='(-9) NO DATA' ;
  VALUE cadtrain  -9='(-9) NO DATA' ;
  VALUE svcelsw   -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE revenue   -9='(-9) NO DATA' -3='(-3) MISSING' ;
  VALUE pctnopay  -9='(-9) NO DATA' -3='(-3) MISSING' 1='(1) 0-50%' 2='(2) 51-99%' 3='(3) 100%' ;
  VALUE totadmit  -9='(-9) NO DATA' 1='(1) 0-100' 2='(2) 101-250' 3='(3) 251+' ;
  VALUE afradmit  -9='(-9) NO DATA' -3='(-3) MISSING' 1='(1) 0-10' 2='(2) 11-100'
                  3='(3) More than 100' ;
  VALUE hspadmit  -9='(-9) NO DATA' 1='(1) 0-5' 2='(2) 6-50' 3='(3) More than 50' ;
  VALUE femadmit  -9='(-9) NO DATA' -3='(-3) MISSING' 1='(1) 0' 2='(2) 1-50' 3='(3) More than 50' ;
  VALUE o21adm    -9='(-9) NO DATA' -3='(-3) MISSING' 1='(1) 0-30' 2='(2) 31-100'
                  3='(3) More than 100' ;
  VALUE actcase   -9='(-9) NO DATA' 1='(1) 1-25' 2='(2) 26-100' 3='(3) More than 100' ;
  VALUE inphase   -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE exphase   -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE ptmatch   -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE freqcoun  -9='(-9) NO DATA' 1='(1) Less than once per week' 2='(2) Once per week'
                  3='(3) More than once per week' ;
  VALUE envchang  -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE fampar    -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE selfimag  -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE urinfreq  -9='(-9) NO DATA' -3='(-3) MISSING' 1='(1) Two or fewer'
                  2='(2) Three or more' ;
  VALUE academic  -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE voctrain  -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE medical   -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE psychiat  -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE pregnan   -9='(-9) NO DATA' 1='(1) Yes' 2='(2) No' ;
  VALUE crslfest  -9='(-9) NO DATA' ;
  VALUE crenvchg  -9='(-9) NO DATA' ;
  VALUE crconbeh  -9='(-9) NO DATA' ;
  VALUE crsocskl  -9='(-9) NO DATA' ;
  VALUE crinfo    -9='(-9) NO DATA' ;
  VALUE crjobed   -9='(-9) NO DATA' ;
  VALUE crmedic   -9='(-9) NO DATA' ;
  VALUE cr12step  -9='(-9) NO DATA' ;
  VALUE crpsych   -9='(-9) NO DATA' ;
  VALUE crpunish  -9='(-9) NO DATA' ;
  VALUE crspirit  -9='(-9) NO DATA' ;
  VALUE crtsting  -9='(-9) NO DATA' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=204;
INPUT
        CASEID 1-7              NUSDUID 8-9             DIRCOLL 10-11
        DIRGRAD 12-13           DIRCRED 14-15           DIRYEARS 16-17
        DIRSEX 18-19            DIRETHNI 20-21          YRSKEYP1 22-23
        YRSKEYP2 24-25          PMALESTF 26-27          PMINOSTF 28-29
        ANYCASE 30-31           FTEMED 32-33            FTECOUNS 34-35
        FTEADMIN 36-37          CTENURE 38-42 .1        CADCASES 43-47 .1
        COLGRAD 48-52 .1        CGENDER 53-56 .1        CGENMTCH 57-61 .1
        CRACE 62-66 .1          CRACMTCH 67-71 .1       CADTRAIN 72-76 .1
        SVCELSW 77-78           REVENUE 79-80           PCTNOPAY 81-82
        TOTADMIT 83-84          AFRADMIT 85-86          HSPADMIT 87-88
        FEMADMIT 89-90          O21ADM 91-92            ACTCASE 93-94
        INPHASE 95-96           EXPHASE 97-98           PTMATCH 99-100
        FREQCOUN 101-102        ENVCHANG 103-104        FAMPAR 105-106
        SELFIMAG 107-108        URINFREQ 109-110        ACADEMIC 111-112
        VOCTRAIN 113-114        MEDICAL 115-116         PSYCHIAT 117-118
        PREGNAN 119-120         CRSLFEST 121-127 .4     CRENVCHG 128-134 .4
        CRCONBEH 135-141 .4     CRSOCSKL 142-148 .4     CRINFO 149-155 .4
        CRJOBED 156-162 .4      CRMEDIC 163-169 .4      CR12STEP 170-176 .4
        CRPSYCH 177-183 .4      CRPUNISH 184-190 .4     CRSPIRIT 191-197 .4
        CRTSTING 198-204 .4     ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   NUSDUID = 'LINKED NEW SDU ID NUMBER'
   DIRCOLL = 'SDU DIRECTOR COLLEGE GRAD'
   DIRGRAD = 'SDU DIRECTOR POSTGRAD DEGREE'
   DIRCRED = 'SDU DIRECTOR OTHER CREDENTIAL'
   DIRYEARS= 'SDU DIRECTOR YEARS AT SDU'
   DIRSEX  = 'SDU DIRECTOR SEX'
   DIRETHNI= 'SDU DIRECTOR ETHNIC MINORITY'
   YRSKEYP1= 'KEY PERSONNEL 1 YRS AT SDU'
   YRSKEYP2= 'KEY PERSONNEL 2 YRS AT SDU'
   PMALESTF= 'PERCENT MALE STAFF'
   PMINOSTF= 'PERCENT MINORITY STAFF'
   ANYCASE = 'ANY CASE MANAGERS'
   FTEMED  = 'MEDICAL STAFF FTES'
   FTECOUNS= 'COUNSELING STAFF FTES'
   FTEADMIN= 'ADMINISTRATIVE STAFF FTES'
   CTENURE = 'SDU: % CLINICIANS SAYING WKED W. PGM FOR'
   CADCASES= 'SDU: % CLINICIANS SAYING ALL THEIR WORK'
   COLGRAD = 'SDU: % CLINICIANS HAVING BACHELOR OR HIG'
   CGENDER = 'SDU: % CLINICIANS WHO WERE MALE'
   CGENMTCH= 'SDU: % CLINICIANS SAYING >= 50% PATIENTS'
   CRACE   = 'SDU: % CLINICIANS SAYING WHO WERE BLACK'
   CRACMTCH= 'SDU: % CLINICIANS SAYING >=50% PATIENTS'
   CADTRAIN= 'SDU: % CLINICIANS HAVING >=261 HRS LIFET'
   SVCELSW = 'PTS GET CSAT$ SERVICES ELSEWHERE'
   REVENUE = 'TOTAL REVENUES OF SDU'
   PCTNOPAY= 'PERCENT OF PATIENTS UNABLE TO PAY HALF O'
   TOTADMIT= 'TOTAL NEW ADMITS IN REF YEAR'
   AFRADMIT= 'AFR-AMER ADMITS IN REF YEAR'
   HSPADMIT= 'HISPANIC ADMITS IN REF YEAR'
   FEMADMIT= 'FEMALE ADMITS IN REF YEAR'
   O21ADM  = 'ADULT (OVER 21) ADMITS IN REF YEAR'
   ACTCASE = 'CURRENT ACTIVE CASELOAD'
   INPHASE = 'TREATMENT PHASED IN THE SDU'
   EXPHASE = 'TREATMENT PHASED WITH OTHER SDUS'
   PTMATCH = 'SDU MATCHES MOST OR ALL PATIENTS WITH CA'
   FREQCOUN= 'HOW OFTEN PTS ATTEND INDIV COUNSELING SE'
   ENVCHANG= 'STRESSES CHANGE OF ENVIRONMENT'
   FAMPAR  = 'STRESSES FAMILY/PARENTING SKILLS'
   SELFIMAG= 'STRESSES SELF-IMAGE/SELF-ESTEEM'
   URINFREQ= 'HOW MANY URINALYSES TYPICALLY DONE'
   ACADEMIC= 'ACADEMIC TRAINING PROVIDED ON SITE'
   VOCTRAIN= 'VOCATIONAL TRAINING PROVIDED ON SITE'
   MEDICAL = 'MEDICAL SERVICES PROVIDED ON SITE'
   PSYCHIAT= 'PSYCHIATRIC SERVICES PROVIDED ON SITE'
   PREGNAN = 'PREGNANCY SERVICES PROVIDED'
   CRSLFEST= 'C.RANK: COUNSEL TO IMPROVE SELF-ESTEEM'
   CRENVCHG= 'C.RANK: ASSIST SOCIAL ENVIRONS CHANGE'
   CRCONBEH= 'C.RANK: COUNSEL TO CONTROL BEHAVIOR'
   CRSOCSKL= 'C.RANK: HELP LEARN SOCIAL/PRACTICAL SKIL'
   CRINFO  = 'C.RANK: INFO ON DRUG EFFECTS & RELEVANT'
   CRJOBED = 'C.RANK: JOB TRAINING/CONTINUING EDUCATIO'
   CRMEDIC = 'C.RANK: MED EXAM, TREATING COND/ILLNESS'
   CR12STEP= 'C.RANK: PARTICIPATION IN 12-STEP MEETING'
   CRPSYCH = 'C.RANK: PSYCHIATRIC WORK-UP/MENTAL HEALT'
   CRPUNISH= 'C.RANK: GOOD & BAD BEHAVIOR REWARDS/PUNI'
   CRSPIRIT= 'C.RANK: SPIRITUAL COUNSELING'
   CRTSTING= 'C.RANK: URINALYSIS, DRUG/ALCOHOL TESTING'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CASEID <= -1) THEN CASEID = .;
   IF (NUSDUID <= -1) THEN NUSDUID = .;
   IF (DIRCOLL <= -1) THEN DIRCOLL = .;
   IF (DIRGRAD <= -1) THEN DIRGRAD = .;
   IF (DIRCRED <= -1) THEN DIRCRED = .;
   IF (DIRYEARS <= -1) THEN DIRYEARS = .;
   IF (DIRSEX <= -1) THEN DIRSEX = .;
   IF (DIRETHNI <= -1) THEN DIRETHNI = .;
   IF (YRSKEYP1 <= -1) THEN YRSKEYP1 = .;
   IF (YRSKEYP2 <= -1) THEN YRSKEYP2 = .;
   IF (PMALESTF <= -1) THEN PMALESTF = .;
   IF (PMINOSTF <= -1) THEN PMINOSTF = .;
   IF (ANYCASE <= -1) THEN ANYCASE = .;
   IF (FTEMED <= -1) THEN FTEMED = .;
   IF (FTECOUNS <= -1) THEN FTECOUNS = .;
   IF (FTEADMIN <= -1) THEN FTEADMIN = .;
   IF (CTENURE <= -1.0) THEN CTENURE = .;
   IF (CADCASES <= -1.0) THEN CADCASES = .;
   IF (COLGRAD <= -1.0) THEN COLGRAD = .;
   IF (CGENDER <= -1.0) THEN CGENDER = .;
   IF (CGENMTCH <= -1.0) THEN CGENMTCH = .;
   IF (CRACE <= -1.0) THEN CRACE = .;
   IF (CRACMTCH <= -1.0) THEN CRACMTCH = .;
   IF (CADTRAIN <= -1.0) THEN CADTRAIN = .;
   IF (SVCELSW <= -1) THEN SVCELSW = .;
   IF (REVENUE <= -1) THEN REVENUE = .;
   IF (PCTNOPAY <= -1) THEN PCTNOPAY = .;
   IF (TOTADMIT <= -1) THEN TOTADMIT = .;
   IF (AFRADMIT <= -1) THEN AFRADMIT = .;
   IF (HSPADMIT <= -1) THEN HSPADMIT = .;
   IF (FEMADMIT <= -1) THEN FEMADMIT = .;
   IF (O21ADM <= -1) THEN O21ADM = .;
   IF (ACTCASE <= -1) THEN ACTCASE = .;
   IF (INPHASE <= -1) THEN INPHASE = .;
   IF (EXPHASE <= -1) THEN EXPHASE = .;
   IF (PTMATCH <= -1) THEN PTMATCH = .;
   IF (FREQCOUN <= -1) THEN FREQCOUN = .;
   IF (ENVCHANG <= -1) THEN ENVCHANG = .;
   IF (FAMPAR <= -1) THEN FAMPAR = .;
   IF (SELFIMAG <= -1) THEN SELFIMAG = .;
   IF (URINFREQ <= -1) THEN URINFREQ = .;
   IF (ACADEMIC <= -1) THEN ACADEMIC = .;
   IF (VOCTRAIN <= -1) THEN VOCTRAIN = .;
   IF (MEDICAL <= -1) THEN MEDICAL = .;
   IF (PSYCHIAT <= -1) THEN PSYCHIAT = .;
   IF (PREGNAN <= -1) THEN PREGNAN = .;
   IF (CRSLFEST <= -1.0000) THEN CRSLFEST = .;
   IF (CRENVCHG <= -1.0000) THEN CRENVCHG = .;
   IF (CRCONBEH <= -1.0000) THEN CRCONBEH = .;
   IF (CRSOCSKL <= -1.0000) THEN CRSOCSKL = .;
   IF (CRINFO <= -1.0000) THEN CRINFO = .;
   IF (CRJOBED <= -1.0000) THEN CRJOBED = .;
   IF (CRMEDIC <= -1.0000) THEN CRMEDIC = .;
   IF (CR12STEP <= -1.0000) THEN CR12STEP = .;
   IF (CRPSYCH <= -1.0000) THEN CRPSYCH = .;
   IF (CRPUNISH <= -1.0000) THEN CRPUNISH = .;
   IF (CRSPIRIT <= -1.0000) THEN CRSPIRIT = .;
   IF (CRTSTING <= -1.0000) THEN CRTSTING = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT DIRCOLL dircoll. DIRGRAD dirgrad. DIRCRED dircred.
         DIRYEARS diryears. DIRSEX dirsex. DIRETHNI direthni.
         YRSKEYP1 yrskeypf. YRSKEYP2 yrskey0f. PMALESTF pmalestf.
         PMINOSTF pminostf. ANYCASE anycase. FTEMED ftemed.
         FTECOUNS ftecouns. FTEADMIN fteadmin. CTENURE ctenure.
         CADCASES cadcases. COLGRAD colgrad. CGENDER cgender.
         CGENMTCH cgenmtch. CRACE crace. CRACMTCH cracmtch.
         CADTRAIN cadtrain. SVCELSW svcelsw. REVENUE revenue.
         PCTNOPAY pctnopay. TOTADMIT totadmit. AFRADMIT afradmit.
         HSPADMIT hspadmit. FEMADMIT femadmit. O21ADM o21adm.
         ACTCASE actcase. INPHASE inphase. EXPHASE exphase.
         PTMATCH ptmatch. FREQCOUN freqcoun. ENVCHANG envchang.
         FAMPAR fampar. SELFIMAG selfimag. URINFREQ urinfreq.
         ACADEMIC academic. VOCTRAIN voctrain. MEDICAL medical.
         PSYCHIAT psychiat. PREGNAN pregnan. CRSLFEST crslfest.
         CRENVCHG crenvchg. CRCONBEH crconbeh. CRSOCSKL crsocskl.
         CRINFO crinfo. CRJOBED crjobed. CRMEDIC crmedic.
         CR12STEP cr12step. CRPSYCH crpsych. CRPUNISH crpunish.
         CRSPIRIT crspirit. CRTSTING crtsting.  ;
*/

RUN ;
